@@ -1,4 +1,4 @@
-#define REMOTE_SCOREBOARD_TYPE "application/x-apache-scoreboard"
+#define REMOTE_SCOREBOARD_TYPE "application/x-httpd-scoreboard"
 
 #ifndef Move
 #define Move(s,d,n,t) (void)memmove((char*)(d),(char*)(s), (n) * sizeof(t)) 
@@ -22,21 +22,24 @@ static unsigned short unpack16(unsigned char *s)
     return ntohs(ashort);
 }
 
+
+#define WRITE_BUFF(buf, size, r) \
+    if (ap_rwrite(buf, size, r) < 0) { return APR_EGENERAL; }
+
 static int scoreboard_send(request_rec *r)
 {
     int i, psize, ssize, tsize;
     char buf[SIZE16*2];
     char *ptr = buf;
 
-    ap_sync_scoreboard_image();
-    for (i=0; i<HARD_SERVER_LIMIT; i++) {
-	if (!ap_scoreboard_image->parent[i].pid) {
-	    break;
-	}
+    for (i = 0; i < server_limit; i++) {
+        if (!ap_scoreboard_image->parent[i].pid) {
+            break;
+        }
     }
-
-    psize = i * sizeof(parent_score);
-    ssize = i * sizeof(short_score);
+    
+    psize = i * sizeof(process_score);
+    ssize = i * sizeof(worker_score);
     tsize = psize + ssize + sizeof(global_score) + sizeof(buf);
 
     pack16(ptr, psize);
@@ -45,14 +48,15 @@ static int scoreboard_send(request_rec *r)
 
     ap_set_content_length(r, tsize);
     r->content_type = REMOTE_SCOREBOARD_TYPE;
-    ap_send_http_header(r);
-
+    
     if (!r->header_only) {
-	ap_rwrite(&buf[0], sizeof(buf), r);
-	ap_rwrite(&ap_scoreboard_image->parent[0], psize, r);
-	ap_rwrite(&ap_scoreboard_image->servers[0], ssize, r);
-	ap_rwrite(&ap_scoreboard_image->global, sizeof(global_score), r);
+	WRITE_BUFF(&buf[0],                          sizeof(buf),          r);
+	WRITE_BUFF(&ap_scoreboard_image->parent[0],  psize,                r);
+	WRITE_BUFF(&ap_scoreboard_image->servers[0], ssize,                r);
+	WRITE_BUFF(&ap_scoreboard_image->global,     sizeof(global_score), r);
     }
 
-    return OK;
+    return APR_SUCCESS;
 }
+
+
